@@ -1,6 +1,6 @@
 package Bio::Roary::CommandLine::Common;
 # ABSTRACT: Common command line settings
-$Bio::Roary::CommandLine::Common::VERSION = '3.6.1';
+$Bio::Roary::CommandLine::Common::VERSION = '3.6.2';
 
 use Moose;
 use FindBin;
@@ -12,7 +12,7 @@ has 'version'                 => ( is => 'rw', isa => 'Bool', default => 0 );
 sub _build_logger
 {
     my ($self) = @_;
-    Log::Log4perl->easy_init(level => $ERROR);
+    Log::Log4perl->easy_init($ERROR);
     my $logger = get_logger();
     return $logger;
 }
@@ -61,7 +61,7 @@ Bio::Roary::CommandLine::Common - Common command line settings
 
 =head1 VERSION
 
-version 3.6.1
+version 3.6.2
 
 =head1 SYNOPSIS
 
